assortedViz-package: Assorted functions for plotting

Description Details Author(s)

Description

A collections of functions that *might be* usefull for plotting data

Details

The DESCRIPTION file: This package was not yet installed at build time.

Index: This package was not yet installed at build time.

Author(s)

Pedro Tarrroso

Maintainer: Pedro Tarroso <ptarroso@cibio.up.pt>


ptarroso/assortedViz documentation built on Oct. 7, 2020, 4:35 a.m.